@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client;
 # ABSTRACT: A comprehensive, DWIM-featured client to the MetaCPAN API
-$MetaCPAN::Client::VERSION = '1.011000';
+$MetaCPAN::Client::VERSION = '1.012000';
 use Moo;
 use Carp;
 
@@ -15,6 +15,7 @@ use MetaCPAN::Client::Favorite;
 use MetaCPAN::Client::Pod;
 use MetaCPAN::Client::Rating;
 use MetaCPAN::Client::Release;
+use MetaCPAN::Client::Mirror;
 use MetaCPAN::Client::ResultSet;
 
 has request => (
@@ -23,7 +24,7 @@ has request => (
 );
 
 my @supported_searches = qw<
-    author distribution favorite module rating release
+    author distribution favorite module rating release mirror
 >;
 
 sub BUILDARGS {
@@ -79,13 +80,6 @@ sub pod {
     return MetaCPAN::Client::Pod->new({ name => $name });
 }
 
-#
-# $api->rating({ dist => "Moose" })
-#   is equal to http://api.metacpan.org/v0/favorite/_search?q=distribution:Moose
-#
-# $api->rating({ author => "DOY" })
-#   is equal to http://api.metacpan.org/v0/favorite/_search?q=author:DOY
-#
 sub favorite {
     my $self   = shift;
     my $args   = shift;
@@ -97,13 +91,6 @@ sub favorite {
     return $self->_search( 'favorite', $args, $params );
 }
 
-#
-# $api->rating({ rating => "4.0" })
-#   is equal to http://api.metacpan.org/v0/rating/_search?q=rating:4.0
-#
-# $api->rating({ distribution => "Moose" })
-#   is equal to http://api.metacpan.org/v0/rating/_search?q=distribution:Moose
-#
 sub rating {
     my $self   = shift;
     my $args   = shift;
@@ -115,10 +102,6 @@ sub rating {
     return $self->_search( 'rating', $args, $params );
 }
 
-#
-# $api->release({ author => "XSAWYERX" })
-#   is equal to http://api.metacpan.org/v0/release/_search?q=author:XSAWYERX
-#
 sub release {
     my $self   = shift;
     my $arg    = shift;
@@ -127,6 +110,14 @@ sub release {
     return $self->_get_or_search( 'release', $arg, $params );
 }
 
+sub mirror {
+    my $self   = shift;
+    my $arg    = shift;
+    my $params = shift;
+
+    return $self->_get_or_search( 'mirror', $arg, $params );
+}
+
 sub reverse_dependencies {
     my $self = shift;
     my $dist = shift;
@@ -159,7 +150,8 @@ sub all {
     my $type   = shift;
     my $params = shift;
 
-    grep { $type eq $_ } qw/ authors distributions modules releases favorites /
+    grep { $type eq $_ } qw/ authors distributions modules releases
+                             favorites ratings mirrors /
         or croak "all: unsupported type";
     $type =~ s/s$//;
 
@@ -344,7 +336,7 @@ MetaCPAN::Client - A comprehensive, DWIM-featured client to the MetaCPAN API
 
 =head1 VERSION
 
-version 1.011000
+version 1.012000
 
 =head1 SYNOPSIS
 
@@ -441,10 +433,14 @@ Return a L<MetaCPAN::Client::File> object.
 
 =head2 favorite
 
+    my $favorite = $mcpan->favorite({ distribution => 'Moose' });
+
 Return a L<MetaCPAN::Client::Favorite> object.
 
 =head2 rating
 
+    my $rating = $mcpan->rating({ distribution => 'Moose' });
+
 Return a L<MetaCPAN::Client::Rating> object.
 
 =head2 release
@@ -460,6 +456,12 @@ Return a L<MetaCPAN::Client::Release> object on a simple search (release name),
 or a L<MetaCPAN::Client::ResultSet> object propagated with
 L<MetaCPAN::Client::Release> objects on a complex (L<search spec based|/"SEARCH SPEC">) search.
 
+=head2 mirror
+
+    my $mirror = $mcpan->mirror('kr.freebsd.org');
+
+Returns a L<MetaCPAN::Client::Mirror> object.
+
 =head2 reverse_dependencies
 
     my $deps = $mcpan->reverse_dependencies('ElasticSearch');
