@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Pod;
 # ABSTRACT: A Pod object
-$MetaCPAN::Client::Pod::VERSION = '1.011000';
+$MetaCPAN::Client::Pod::VERSION = '1.012000';
 use Moo;
 
 has name => ( is => 'ro', required => 1 );
@@ -53,7 +53,7 @@ MetaCPAN::Client::Pod - A Pod object
 
 =head1 VERSION
 
-version 1.011000
+version 1.012000
 
 =head1 SYNOPSIS
 
@@ -71,14 +71,24 @@ version 1.011000
 
 =head2 name
 
+The name of the module (probably always the value passed to the pod() method)
+
 =head2 x_pod
 
+The raw pod extracted from the file.
+
 =head2 html
 
+Formatted as an HTML chunk (No <html>...<body>)
+
 =head2 x_markdown
 
+Converted to Markdown.
+
 =head2 plain
 
+Formatted as plain text.
+
 Get the plaintext version of the documentation
 
   $pod = MetaCPAN::Client->new->pod( "MetaCPAN::Client" );
