@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::ResultSet;
 # ABSTRACT: A Result Set
-$MetaCPAN::Client::ResultSet::VERSION = '1.011000';
+$MetaCPAN::Client::ResultSet::VERSION = '1.012000';
 use Moo;
 use Carp;
 
@@ -11,7 +11,7 @@ has type => (
     isa      => sub {
         croak 'Invalid type' unless
             grep { $_ eq $_[0] } qw<author distribution favorite
-                                   file module rating release>;
+                                   file module rating release mirror>;
     },
     required => 1,
 );
@@ -89,7 +89,7 @@ MetaCPAN::Client::ResultSet - A Result Set
 
 =head1 VERSION
 
-version 1.011000
+version 1.012000
 
 =head1 DESCRIPTION
 
